@@ -10,11 +10,12 @@ var configScriptLoaded;
 /**
  * checks whether browser supports web storage
  *
- * @param type the type of storage i.e. localStorage or sessionStorage
+ * @param {'localStorage' | 'sessionStorage'} type the type of storage i.e. localStorage or sessionStorage
+ * @param {boolean} warn Wether to show a warning on error
  *
- * @returns bool
+ * @return {boolean}
  */
-function isStorageSupported (type, warn) {
+function isStorageSupported (type, warn = false) {
     try {
         window[type].setItem('PMATest', 'test');
         // Check whether key-value pair was set successfully
@@ -38,7 +39,7 @@ function isStorageSupported (type, warn) {
 AJAX.registerTeardown('config.js', function () {
     $('.optbox input[id], .optbox select[id], .optbox textarea[id]').off('change').off('keyup');
     $('.optbox input[type=button][name=submit_reset]').off('click');
-    $('div.tabs_contents').off();
+    $('div.tab-content').off();
     $('#import_local_storage, #export_local_storage').off('click');
     $('form.prefs-form').off('change').off('submit');
     $(document).off('click', 'div.click-hide-message');
@@ -58,6 +59,8 @@ var defaultValues = {};
  * Returns field type
  *
  * @param {Element} field
+ *
+ * @return {string}
  */
 function getFieldType (field) {
     var $field = $(field);
@@ -77,6 +80,8 @@ function getFieldType (field) {
  *
  * @param {Element} field
  * @param {boolean} display
+ *
+ * @return {void}
  */
 function setRestoreDefaultBtn (field, display) {
     var $el = $(field).closest('td').find('.restore-default img');
@@ -86,7 +91,9 @@ function setRestoreDefaultBtn (field, display) {
 /**
  * Marks field depending on its value (system default or custom)
  *
- * @param {Element} field
+ * @param {Element | JQuery<Element>} field
+ *
+ * @return {void}
  */
 function markField (field) {
     var $field = $(field);
@@ -109,8 +116,8 @@ function markField (field) {
  * o Array of values - if field_type is 'select'
  *
  * @param {Element} field
- * @param {String}  fieldType  see {@link #getFieldType}
- * @param {String|Boolean}  value
+ * @param {string}  fieldType see {@link #getFieldType}
+ * @param {string | boolean}  value
  */
 function setFieldValue (field, fieldType, value) {
     var $field = $(field);
@@ -143,8 +150,9 @@ function setFieldValue (field, fieldType, value) {
  * o Array of values - if type is 'select'
  *
  * @param {Element} field
- * @param {String}  fieldType returned by {@link #getFieldType}
- * @type Boolean|String|String[]
+ * @param {string}  fieldType returned by {@link #getFieldType}
+ *
+ * @return {boolean | string | string[] | null}
  */
 function getFieldValue (field, fieldType) {
     var $field = $(field);
@@ -171,6 +179,8 @@ function getFieldValue (field, fieldType) {
 
 /**
  * Returns values for all fields in fieldsets
+ *
+ * @return {object}
  */
 // eslint-disable-next-line no-unused-vars
 function getAllValues () {
@@ -196,8 +206,9 @@ function getAllValues () {
  * Checks whether field has its default value
  *
  * @param {Element} field
- * @param {String}  type
- * @return boolean
+ * @param {string}  type
+ *
+ * @return {boolean}
  */
 function checkFieldDefault (field, type) {
     var $field = $(field);
@@ -228,6 +239,8 @@ function checkFieldDefault (field, type) {
 /**
  * Returns element's id prefix
  * @param {Element} element
+ *
+ * @return {string}
  */
 // eslint-disable-next-line no-unused-vars
 function getIdPrefix (element) {
@@ -251,6 +264,8 @@ var validators = {
      * Validates positive number
      *
      * @param {boolean} isKeyUp
+     *
+     * @return {boolean}
      */
     validatePositiveNumber: function (isKeyUp) {
         if (isKeyUp && this.value === '') {
@@ -263,6 +278,8 @@ var validators = {
      * Validates non-negative number
      *
      * @param {boolean} isKeyUp
+     *
+     * @return {boolean}
      */
     validateNonNegativeNumber: function (isKeyUp) {
         if (isKeyUp && this.value === '') {
@@ -273,6 +290,8 @@ var validators = {
     },
     /**
      * Validates port number
+     *
+     * @return {true|string}
      */
     validatePortNumber: function () {
         if (this.value === '') {
@@ -286,6 +305,8 @@ var validators = {
      *
      * @param {boolean} isKeyUp
      * @param {string}  regexp
+     *
+     * @return {true|string}
      */
     validateByRegex: function (isKeyUp, regexp) {
         if (isKeyUp && this.value === '') {
@@ -300,7 +321,9 @@ var validators = {
      * Validates upper bound for numeric inputs
      *
      * @param {boolean} isKeyUp
-     * @param {int} maxValue
+     * @param {number} maxValue
+     *
+     * @return {true|string}
      */
     validateUpperBound: function (isKeyUp, maxValue) {
         var val = parseInt(this.value, 10);
@@ -320,8 +343,8 @@ var validators = {
 /**
  * Registers validator for given field
  *
- * @param {String}  id       field id
- * @param {String}  type     validator (key in validators object)
+ * @param {string}  id       field id
+ * @param {string}  type     validator (key in validators object)
  * @param {boolean} onKeyUp  whether fire on key up
  * @param {Array}   params   validation function parameters
  */
@@ -342,9 +365,9 @@ function registerFieldValidator (id, type, onKeyUp, params) {
  * Returns validation functions associated with form field
  *
  * @param {String}  fieldId     form field id
- * @param {boolean} onKeyUpOnly  see registerFieldValidator
- * @type Array
- * @return array of [function, parameters to be passed to function]
+ * @param {boolean} onKeyUpOnly see registerFieldValidator
+ *
+ * @return {any[]} of [function, parameters to be passed to function]
  */
 function getFieldValidators (fieldId, onKeyUpOnly) {
     // look for field bound validator
@@ -374,7 +397,7 @@ function getFieldValidators (fieldId, onKeyUpOnly) {
  * WARNING: created DOM elements must be identical with the ones made by
  * PhpMyAdmin\Config\FormDisplayTemplate::displayInput()!
  *
- * @param {Object} errorList list of errors in the form {field id: error array}
+ * @param {object} errorList list of errors in the form {field id: error array}
  */
 function displayErrors (errorList) {
     var tempIsEmpty = function (item) {
@@ -448,7 +471,7 @@ function setDisplayError () {
  *
  * @param {Element} fieldset
  * @param {boolean} isKeyUp
- * @param {Object}  errors
+ * @param {object}  errors
  */
 function validateFieldset (fieldset, isKeyUp, errors) {
     var $fieldset = $(fieldset);
@@ -471,7 +494,7 @@ function validateFieldset (fieldset, isKeyUp, errors) {
  *
  * @param {Element} field
  * @param {boolean} isKeyUp
- * @param {Object}  errors
+ * @param {object}  errors
  */
 function validateField (field, isKeyUp, errors) {
     var args;
@@ -579,51 +602,6 @@ AJAX.registerOnload('config.js', function () {
 // END: Form validation and field operations
 // ------------------------------------------------------------------
 
-// ------------------------------------------------------------------
-// Tabbed forms
-//
-
-/**
- * Sets active tab
- *
- * @param {String} tabId
- */
-function setTab (tabId) {
-    $('ul.tabs').each(function () {
-        var $this = $(this);
-        if (!$this.find('li a[href="#' + tabId + '"]').length) {
-            return;
-        }
-        $this.find('li').removeClass('active').find('a[href="#' + tabId + '"]').parent().addClass('active');
-        $this.parent().find('div.tabs_contents fieldset').hide().filter('#' + tabId).show();
-        var hashValue = 'tab_' + tabId;
-        location.hash = hashValue;
-        $this.parent().find('input[name=tab_hash]').val(hashValue);
-    });
-}
-
-function setupConfigTabs () {
-    var forms = $('form.config-form');
-    forms.each(function () {
-        var $this = $(this);
-        var $tabs = $this.find('ul.tabs');
-        if (!$tabs.length) {
-            return;
-        }
-        // add tabs events and activate one tab (the first one or indicated by location hash)
-        $tabs.find('li').removeClass('active');
-        $tabs.find('a')
-            .on('click', function (e) {
-                e.preventDefault();
-                setTab($(this).attr('href').substr(1));
-            })
-            .first()
-            .parent()
-            .addClass('active');
-        $this.find('div.tabs_contents fieldset').hide().first().show();
-    });
-}
-
 function adjustPrefsNotification () {
     var $prefsAutoLoad = $('#prefs_autoload');
     var $tableNameControl = $('#table_name_col_no');
@@ -635,27 +613,9 @@ function adjustPrefsNotification () {
 }
 
 AJAX.registerOnload('config.js', function () {
-    setupConfigTabs();
     adjustPrefsNotification();
-
-    // tab links handling
-    // (works with history in FF, further browser support here would be an overkill)
-    window.onhashchange = function () {
-        if (location.hash.match(/^#tab_[a-zA-Z0-9_]+$/)) {
-            // session ID is sometimes appended here
-            var hash = location.hash.substr(5).split('&')[0];
-            if ($('#' + hash).length) {
-                setTab(hash);
-            }
-        }
-    };
-    window.onhashchange();
 });
 
-//
-// END: Tabbed forms
-// ------------------------------------------------------------------
-
 // ------------------------------------------------------------------
 // Form reset buttons
 //
@@ -681,7 +641,9 @@ AJAX.registerOnload('config.js', function () {
 /**
  * Restores field's default value
  *
- * @param {String} fieldId
+ * @param {string} fieldId
+ *
+ * @return {void}
  */
 function restoreField (fieldId) {
     var $field = $('#' + fieldId);
@@ -692,7 +654,7 @@ function restoreField (fieldId) {
 }
 
 function setupRestoreField () {
-    $('div.tabs_contents')
+    $('div.tab-content')
         .on('mouseenter', '.restore-default, .set-value', function () {
             $(this).css('opacity', 1);
         })
