@@ -1,675 +1,729 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * Hold the PhpMyAdmin\LanguageManager class
- *
- * @package PhpMyAdmin
- */
+
+declare(strict_types=1);
+
 namespace PhpMyAdmin;
 
-use PhpMyAdmin\Core;
-use PhpMyAdmin\Language;
-use PhpMyAdmin\Template;
-use PhpMyAdmin\Url;
-use PhpMyAdmin\Util;
+use function __;
+use function closedir;
+use function count;
+use function explode;
+use function file_exists;
+use function is_dir;
+use function opendir;
+use function preg_grep;
+use function readdir;
+use function strtolower;
+use function trigger_error;
+use function uasort;
+use function ucfirst;
+
+use const E_USER_ERROR;
 
 /**
  * Language selection manager
- *
- * @package PhpMyAdmin
  */
 class LanguageManager
 {
     /**
-     * @var array Definition data for languages
+     * Definition data for languages
      *
      * Each member contains:
      * - Language code
      * - English language name
      * - Native language name
-     * - Match regullar expression
+     * - Match regular expression
      * - MySQL locale
+     *
+     * @var array<string, string[]>
+     * @psalm-var array<string, array{non-empty-string, non-empty-string, string, non-empty-string, string}>
      */
-    private static $_language_data = array(
-        'af' => array(
+    private static $languageData = [
+        'af' => [
             'af',
             'Afrikaans',
             '',
             'af|afrikaans',
             '',
-        ),
-        'am' => array(
+        ],
+        'am' => [
             'am',
             'Amharic',
             'አማርኛ',
             'am|amharic',
             '',
-        ),
-        'ar' => array(
+        ],
+        'ar' => [
             'ar',
             'Arabic',
             '&#1575;&#1604;&#1593;&#1585;&#1576;&#1610;&#1577;',
             'ar|arabic',
             'ar_AE',
-        ),
-        'az' => array(
+        ],
+        'ar_ly' => [
+            'ar_LY',
+            'Arabic (Libya)',
+            'ليبي',
+            'ar[_-]ly|arabic (libya)|libian arabic',
+            'ar_LY',
+        ],
+        'az' => [
             'az',
             'Azerbaijani',
             'Az&#601;rbaycanca',
             'az|azerbaijani',
             '',
-        ),
-        'bn' => array(
+        ],
+        'bn' => [
             'bn',
             'Bangla',
             'বাংলা',
             'bn|bangla',
             '',
-        ),
-        'be' => array(
+        ],
+        'be' => [
             'be',
             'Belarusian',
             '&#1041;&#1077;&#1083;&#1072;&#1088;&#1091;&#1089;&#1082;&#1072;&#1103;',
             'be|belarusian',
             'be_BY',
-        ),
-        'be@latin' => array(
+        ],
+        'be@latin' => [
             'be@latin',
             'Belarusian (latin)',
             'Bie&#0322;aruskaja',
             'be[-_]lat|be@latin|belarusian latin',
             '',
-        ),
-        'bg' => array(
+        ],
+        'ber' => [
+            'ber',
+            'Berber',
+            'Tamaziɣt',
+            'ber|berber',
+            '',
+        ],
+        'bg' => [
             'bg',
             'Bulgarian',
             '&#1041;&#1098;&#1083;&#1075;&#1072;&#1088;&#1089;&#1082;&#1080;',
             'bg|bulgarian',
             'bg_BG',
-        ),
-        'bs' => array(
+        ],
+        'bs' => [
             'bs',
             'Bosnian',
             'Bosanski',
             'bs|bosnian',
             '',
-        ),
-        'br' => array(
+        ],
+        'br' => [
             'br',
             'Breton',
             'Brezhoneg',
             'br|breton',
             '',
-        ),
-        'brx' => array(
+        ],
+        'brx' => [
             'brx',
             'Bodo',
             'बड़ो',
             'brx|bodo',
             '',
-        ),
-        'ca' => array(
+        ],
+        'ca' => [
             'ca',
             'Catalan',
             'Catal&agrave;',
             'ca|catalan',
             'ca_ES',
-        ),
-        'ckb' => array(
+        ],
+        'ckb' => [
             'ckb',
             'Sorani',
             'سۆرانی',
             'ckb|sorani',
             '',
-        ),
-        'cs' => array(
+        ],
+        'cs' => [
             'cs',
             'Czech',
             'Čeština',
             'cs|czech',
             'cs_CZ',
-        ),
-        'cy' => array(
+        ],
+        'cy' => [
             'cy',
             'Welsh',
             'Cymraeg',
             'cy|welsh',
             '',
-        ),
-        'da' => array(
+        ],
+        'da' => [
             'da',
             'Danish',
             'Dansk',
             'da|danish',
             'da_DK',
-        ),
-        'de' => array(
+        ],
+        'de' => [
             'de',
             'German',
             'Deutsch',
             'de|german',
             'de_DE',
-        ),
-        'el' => array(
+        ],
+        'el' => [
             'el',
             'Greek',
             '&Epsilon;&lambda;&lambda;&eta;&nu;&iota;&kappa;&#940;',
             'el|greek',
             '',
-        ),
-        'en' => array(
+        ],
+        'en' => [
             'en',
             'English',
             '',
             'en|english',
             'en_US',
-        ),
-        'en_gb' => array(
+        ],
+        'en_gb' => [
             'en_GB',
             'English (United Kingdom)',
             '',
             'en[_-]gb|english (United Kingdom)',
             'en_GB',
-        ),
-        'eo' => array(
+        ],
+        'enm' => [
+            'enm',
+            'English (Middle)',
+            '',
+            'enm|english (middle)',
+            '',
+        ],
+        'eo' => [
             'eo',
             'Esperanto',
             'Esperanto',
             'eo|esperanto',
             '',
-        ),
-        'es' => array(
+        ],
+        'es' => [
             'es',
             'Spanish',
             'Espa&ntilde;ol',
             'es|spanish',
             'es_ES',
-        ),
-        'et' => array(
+        ],
+        'et' => [
             'et',
             'Estonian',
             'Eesti',
             'et|estonian',
             'et_EE',
-        ),
-        'eu' => array(
+        ],
+        'eu' => [
             'eu',
             'Basque',
             'Euskara',
             'eu|basque',
             'eu_ES',
-        ),
-        'fa' => array(
+        ],
+        'fa' => [
             'fa',
             'Persian',
             '&#1601;&#1575;&#1585;&#1587;&#1740;',
             'fa|persian',
             '',
-        ),
-        'fi' => array(
+        ],
+        'fi' => [
             'fi',
             'Finnish',
             'Suomi',
             'fi|finnish',
             'fi_FI',
-        ),
-        'fil' => array(
+        ],
+        'fil' => [
             'fil',
             'Filipino',
             'Pilipino',
             'fil|filipino',
             '',
-        ),
-        'fr' => array(
+        ],
+        'fr' => [
             'fr',
             'French',
             'Fran&ccedil;ais',
             'fr|french',
             'fr_FR',
-        ),
-        'fy' => array(
+        ],
+        'fy' => [
             'fy',
             'Frisian',
             'Frysk',
             'fy|frisian',
             '',
-        ),
-        'gl' => array(
+        ],
+        'gl' => [
             'gl',
             'Galician',
             'Galego',
             'gl|galician',
             'gl_ES',
-        ),
-        'gu' => array(
+        ],
+        'gu' => [
             'gu',
             'Gujarati',
             'ગુજરાતી',
             'gu|gujarati',
             'gu_IN',
-        ),
-        'he' => array(
+        ],
+        'he' => [
             'he',
             'Hebrew',
             '&#1506;&#1489;&#1512;&#1497;&#1514;',
             'he|hebrew',
             'he_IL',
-        ),
-        'hi' => array(
+        ],
+        'hi' => [
             'hi',
             'Hindi',
             '&#2361;&#2367;&#2344;&#2381;&#2342;&#2368;',
             'hi|hindi',
             'hi_IN',
-        ),
-        'hr' => array(
+        ],
+        'hr' => [
             'hr',
             'Croatian',
             'Hrvatski',
             'hr|croatian',
             'hr_HR',
-        ),
-        'hu' => array(
+        ],
+        'hu' => [
             'hu',
             'Hungarian',
             'Magyar',
             'hu|hungarian',
             'hu_HU',
-        ),
-        'hy' => array(
+        ],
+        'hy' => [
             'hy',
             'Armenian',
             'Հայերէն',
             'hy|armenian',
             '',
-        ),
-        'ia' => array(
+        ],
+        'ia' => [
             'ia',
             'Interlingua',
             '',
             'ia|interlingua',
             '',
-        ),
-        'id' => array(
+        ],
+        'id' => [
             'id',
             'Indonesian',
             'Bahasa Indonesia',
             'id|indonesian',
             'id_ID',
-        ),
-        'ig' => array(
+        ],
+        'ig' => [
             'ig',
             'Igbo',
             'Asụsụ Igbo',
             'ig|igbo',
             '',
-        ),
-        'it' => array(
+        ],
+        'it' => [
             'it',
             'Italian',
             'Italiano',
             'it|italian',
             'it_IT',
-        ),
-        'ja' => array(
+        ],
+        'ja' => [
             'ja',
             'Japanese',
             '&#26085;&#26412;&#35486;',
             'ja|japanese',
             'ja_JP',
-        ),
-        'ko' => array(
+        ],
+        'ko' => [
             'ko',
             'Korean',
             '&#54620;&#44397;&#50612;',
             'ko|korean',
             'ko_KR',
-        ),
-        'ka' => array(
+        ],
+        'ka' => [
             'ka',
             'Georgian',
             '&#4325;&#4304;&#4320;&#4311;&#4323;&#4314;&#4312;',
             'ka|georgian',
             '',
-        ),
-        'kab' => array(
+        ],
+        'kab' => [
             'kab',
             'Kabylian',
             'Taqbaylit',
             'kab|kabylian',
             '',
-        ),
-        'kk' => array(
+        ],
+        'kk' => [
             'kk',
             'Kazakh',
             'Қазақ',
             'kk|kazakh',
             '',
-        ),
-        'km' => array(
+        ],
+        'km' => [
             'km',
             'Khmer',
             'ខ្មែរ',
             'km|khmer',
             '',
-        ),
-        'kn' => array(
+        ],
+        'kn' => [
             'kn',
             'Kannada',
             'ಕನ್ನಡ',
             'kn|kannada',
             '',
-        ),
-        'ksh' => array(
+        ],
+        'ksh' => [
             'ksh',
             'Colognian',
             'Kölsch',
             'ksh|colognian',
             '',
-        ),
-        'ku' => array(
+        ],
+        'ku' => [
             'ku',
             'Kurdish',
             'کوردی',
             'ku|kurdish',
             '',
-        ),
-        'ky' => array(
+        ],
+        'ky' => [
             'ky',
             'Kyrgyz',
             'Кыргызча',
             'ky|kyrgyz',
             '',
-        ),
-        'li' => array(
+        ],
+        'li' => [
             'li',
             'Limburgish',
             'Lèmbörgs',
             'li|limburgish',
             '',
-        ),
-        'lt' => array(
+        ],
+        'lt' => [
             'lt',
             'Lithuanian',
             'Lietuvi&#371;',
             'lt|lithuanian',
             'lt_LT',
-        ),
-        'lv' => array(
+        ],
+        'lv' => [
             'lv',
             'Latvian',
             'Latvie&scaron;u',
             'lv|latvian',
             'lv_LV',
-        ),
-        'mk' => array(
+        ],
+        'mk' => [
             'mk',
             'Macedonian',
             'Macedonian',
             'mk|macedonian',
             'mk_MK',
-        ),
-        'ml' => array(
+        ],
+        'ml' => [
             'ml',
             'Malayalam',
             'Malayalam',
             'ml|malayalam',
             '',
-        ),
-        'mn' => array(
+        ],
+        'mn' => [
             'mn',
             'Mongolian',
             '&#1052;&#1086;&#1085;&#1075;&#1086;&#1083;',
             'mn|mongolian',
             'mn_MN',
-        ),
-        'ms' => array(
+        ],
+        'ms' => [
             'ms',
             'Malay',
             'Bahasa Melayu',
             'ms|malay',
             'ms_MY',
-        ),
-        'my' => array(
+        ],
+        'my' => [
             'my',
             'Burmese',
             'မြန်မာ',
             'my|burmese',
             '',
-        ),
-        'ne' => array(
+        ],
+        'ne' => [
             'ne',
             'Nepali',
             'नेपाली',
             'ne|nepali',
             '',
-        ),
-        'nb' => array(
+        ],
+        'nb' => [
             'nb',
             'Norwegian',
             'Norsk',
             'nb|norwegian',
             'nb_NO',
-        ),
-        'nn' => array(
+        ],
+        'nn' => [
             'nn',
             'Norwegian Nynorsk',
             'Nynorsk',
             'nn|nynorsk',
             'nn_NO',
-        ),
-        'nl' => array(
+        ],
+        'nl' => [
             'nl',
             'Dutch',
             'Nederlands',
             'nl|dutch',
             'nl_NL',
-        ),
-        'pa' => array(
+        ],
+        'pa' => [
             'pa',
             'Punjabi',
             'ਪੰਜਾਬੀ',
             'pa|punjabi',
             '',
-        ),
-        'pl' => array(
+        ],
+        'pl' => [
             'pl',
             'Polish',
             'Polski',
             'pl|polish',
             'pl_PL',
-        ),
-        'pt_br' => array(
-            'pt_BR',
-            'Brazilian Portuguese',
-            'Portugu&ecirc;s',
-            'pt[-_]br|brazilian portuguese',
-            'pt_BR',
-        ),
-        'pt' => array(
+        ],
+        'pt' => [
             'pt',
             'Portuguese',
             'Portugu&ecirc;s',
             'pt|portuguese',
             'pt_PT',
-        ),
-        'ro' => array(
+        ],
+        'pt_br' => [
+            'pt_BR',
+            'Portuguese (Brazil)',
+            'Portugu&ecirc;s (Brasil)',
+            'pt[-_]br|portuguese (brazil)',
+            'pt_BR',
+        ],
+        'rcf' => [
+            'rcf',
+            'R&eacute;union Creole',
+            'Kr&eacute;ol',
+            'rcf|creole (reunion)',
+            '',
+        ],
+        'ro' => [
             'ro',
             'Romanian',
             'Rom&acirc;n&#259;',
             'ro|romanian',
             'ro_RO',
-        ),
-        'ru' => array(
+        ],
+        'ru' => [
             'ru',
             'Russian',
             '&#1056;&#1091;&#1089;&#1089;&#1082;&#1080;&#1081;',
             'ru|russian',
             'ru_RU',
-        ),
-        'si' => array(
+        ],
+        'si' => [
             'si',
             'Sinhala',
             '&#3523;&#3538;&#3458;&#3524;&#3517;',
             'si|sinhala',
             '',
-        ),
-        'sk' => array(
+        ],
+        'sk' => [
             'sk',
             'Slovak',
             'Sloven&#269;ina',
             'sk|slovak',
             'sk_SK',
-        ),
-        'sl' => array(
+        ],
+        'sl' => [
             'sl',
             'Slovenian',
             'Sloven&scaron;&#269;ina',
             'sl|slovenian',
             'sl_SI',
-        ),
-        'sq' => array(
+        ],
+        'sq' => [
             'sq',
             'Albanian',
             'Shqip',
             'sq|albanian',
             'sq_AL',
-        ),
-        'sr@latin' => array(
+        ],
+        'sr@latin' => [
             'sr@latin',
             'Serbian (latin)',
             'Srpski',
             'sr[-_]lat|sr@latin|serbian latin',
             'sr_YU',
-        ),
-        'sr' => array(
+        ],
+        'sr' => [
             'sr',
             'Serbian',
             '&#1057;&#1088;&#1087;&#1089;&#1082;&#1080;',
             'sr|serbian',
             'sr_YU',
-        ),
-        'sv' => array(
+        ],
+        'sv' => [
             'sv',
             'Swedish',
             'Svenska',
             'sv|swedish',
             'sv_SE',
-        ),
-        'ta' => array(
+        ],
+        'ta' => [
             'ta',
             'Tamil',
             'தமிழ்',
             'ta|tamil',
             'ta_IN',
-        ),
-        'te' => array(
+        ],
+        'te' => [
             'te',
             'Telugu',
             'తెలుగు',
             'te|telugu',
             'te_IN',
-        ),
-        'th' => array(
+        ],
+        'th' => [
             'th',
             'Thai',
             '&#3616;&#3634;&#3625;&#3634;&#3652;&#3607;&#3618;',
             'th|thai',
             'th_TH',
-        ),
-        'tk' => array(
+        ],
+        'tk' => [
             'tk',
             'Turkmen',
             'Türkmençe',
             'tk|turkmen',
             '',
-        ),
-        'tr' => array(
+        ],
+        'tr' => [
             'tr',
             'Turkish',
             'T&uuml;rk&ccedil;e',
             'tr|turkish',
             'tr_TR',
-        ),
-        'tt' => array(
+        ],
+        'tt' => [
             'tt',
             'Tatarish',
             'Tatar&ccedil;a',
             'tt|tatarish',
             '',
-        ),
-        'ug' => array(
+        ],
+        'tzm' => [
+            'tzm',
+            'Central Atlas Tamazight',
+            'Tamaziɣt',
+            'tzm|central atlas tamazight',
+            '',
+        ],
+        'ug' => [
             'ug',
             'Uyghur',
             'ئۇيغۇرچە',
             'ug|uyghur',
             '',
-        ),
-        'uk' => array(
+        ],
+        'uk' => [
             'uk',
             'Ukrainian',
             '&#1059;&#1082;&#1088;&#1072;&#1111;&#1085;&#1089;&#1100;&#1082;&#1072;',
             'uk|ukrainian',
             'uk_UA',
-        ),
-        'ur' => array(
+        ],
+        'ur' => [
             'ur',
             'Urdu',
             'اُردوُ',
             'ur|urdu',
             'ur_PK',
-        ),
-        'uz@latin' => array(
+        ],
+        'uz@latin' => [
             'uz@latin',
             'Uzbek (latin)',
             'O&lsquo;zbekcha',
             'uz[-_]lat|uz@latin|uzbek-latin',
             '',
-        ),
-        'uz' => array(
+        ],
+        'uz' => [
             'uz',
             'Uzbek (cyrillic)',
             '&#1038;&#1079;&#1073;&#1077;&#1082;&#1095;&#1072;',
             'uz[-_]cyr|uz@cyrillic|uzbek-cyrillic',
             '',
-        ),
-        'vi' => array(
+        ],
+        'vi' => [
             'vi',
             'Vietnamese',
             'Tiếng Việt',
             'vi|vietnamese',
             'vi_VN',
-        ),
-        'vls' => array(
+        ],
+        'vls' => [
             'vls',
             'Flemish',
             'West-Vlams',
             'vls|flemish',
             '',
-        ),
-        'zh_tw' => array(
+        ],
+        'zh_tw' => [
             'zh_TW',
             'Chinese traditional',
             '&#20013;&#25991;',
             'zh[-_](tw|hk)|chinese traditional',
             'zh_TW',
-        ),
+        ],
         // only TW and HK use traditional Chinese while others (CN, SG, MY)
         // use simplified Chinese
-        'zh_cn' => array(
+        'zh_cn' => [
             'zh_CN',
             'Chinese simplified',
             '&#20013;&#25991;',
             'zh(?![-_](tw|hk))([-_][[:alpha:]]{2,3})?|chinese simplified',
             'zh_CN',
-        ),
-    );
+        ],
+    ];
 
-    private $_available_locales;
-    private $_available_languages;
-    private $_lang_failed_cfg;
-    private $_lang_failed_cookie;
-    private $_lang_failed_request;
+    /** @var array */
+    private $availableLocales;
+
+    /** @var array */
+    private $availableLanguages = [];
+
+    /** @var bool */
+    private $langFailedConfig = false;
+
+    /** @var bool */
+    private $langFailedCookie = false;
+
+    /** @var bool */
+    private $langFailedRequest = false;
+
+    /** @var LanguageManager */
     private static $instance;
 
     /**
@@ -680,8 +734,9 @@ class LanguageManager
     public static function getInstance()
     {
         if (self::$instance === null) {
-            self::$instance = new LanguageManager;
+            self::$instance = new LanguageManager();
         }
+
         return self::$instance;
     }
 
@@ -692,10 +747,10 @@ class LanguageManager
      */
     public function listLocaleDir()
     {
-        $result = array('en');
+        $result = ['en'];
 
         /* Check for existing directory */
-        if (!is_dir(LOCALE_PATH)) {
+        if (! is_dir(LOCALE_PATH)) {
             return $result;
         }
 
@@ -707,17 +762,17 @@ class LanguageManager
         }
 
         /* Process all files */
-        while (false !== ($file = readdir($handle))) {
+        while (($file = readdir($handle)) !== false) {
             $path = LOCALE_PATH
                 . '/' . $file
                 . '/LC_MESSAGES/phpmyadmin.mo';
-            if ($file != "."
-                && $file != ".."
-                && @file_exists($path)
-            ) {
-                $result[] = $file;
+            if ($file === '.' || $file === '..' || ! @file_exists($path)) {
+                continue;
             }
+
+            $result[] = $file;
         }
+
         /* Close the handle */
         closedir($handle);
 
@@ -731,26 +786,24 @@ class LanguageManager
      */
     public function availableLocales()
     {
-        if (! $this->_available_locales) {
-
-            if (! isset($GLOBALS['PMA_Config']) || empty($GLOBALS['PMA_Config']->get('FilterLanguages'))) {
-                $this->_available_locales = $this->listLocaleDir();
+        if (! $this->availableLocales) {
+            if (! isset($GLOBALS['config']) || empty($GLOBALS['config']->get('FilterLanguages'))) {
+                $this->availableLocales = $this->listLocaleDir();
             } else {
-                $this->_available_locales = preg_grep(
-                    '@' . $GLOBALS['PMA_Config']->get('FilterLanguages') . '@',
+                $this->availableLocales = preg_grep(
+                    '@' . $GLOBALS['config']->get('FilterLanguages') . '@',
                     $this->listLocaleDir()
                 );
             }
         }
-        return $this->_available_locales;
+
+        return $this->availableLocales;
     }
 
     /**
      * Checks whether there are some languages available
-     *
-     * @return boolean
      */
-    public function hasChoice()
+    public function hasChoice(): bool
     {
         return count($this->availableLanguages()) > 1;
     }
@@ -758,26 +811,20 @@ class LanguageManager
     /**
      * Returns (cached) list of all available languages
      *
-     * @return array of Language objects
+     * @return Language[] array of Language objects
      */
     public function availableLanguages()
     {
-        if (! $this->_available_languages) {
-            $this->_available_languages = array();
+        if (! $this->availableLanguages) {
+            $this->availableLanguages = [];
 
-            foreach($this->availableLocales() as $lang) {
+            foreach ($this->availableLocales() as $lang) {
                 $lang = strtolower($lang);
-                if (isset($this::$_language_data[$lang])) {
-                    $data = $this::$_language_data[$lang];
-                    $this->_available_languages[$lang] = new Language(
-                        $data[0],
-                        $data[1],
-                        $data[2],
-                        $data[3],
-                        $data[4]
-                    );
+                if (isset(static::$languageData[$lang])) {
+                    $data = static::$languageData[$lang];
+                    $this->availableLanguages[$lang] = new Language($data[0], $data[1], $data[2], $data[3], $data[4]);
                 } else {
-                    $this->_available_languages[$lang] = new Language(
+                    $this->availableLanguages[$lang] = new Language(
                         $lang,
                         ucfirst($lang),
                         ucfirst($lang),
@@ -787,24 +834,24 @@ class LanguageManager
                 }
             }
         }
-        return $this->_available_languages;
+
+        return $this->availableLanguages;
     }
 
     /**
      * Returns (cached) list of all available languages sorted
      * by name
      *
-     * @return array of Language objects
+     * @return Language[] array of Language objects
      */
     public function sortedLanguages()
     {
         $this->availableLanguages();
-        uasort($this->_available_languages, function($a, $b)
-            {
-                return $a->cmp($b);
-            }
-        );
-        return $this->_available_languages;
+        uasort($this->availableLanguages, static function (Language $a, Language $b) {
+            return $a->cmp($b);
+        });
+
+        return $this->availableLanguages;
     }
 
     /**
@@ -812,7 +859,7 @@ class LanguageManager
      *
      * @param string $code Language code
      *
-     * @return object|false Language object or false on failure
+     * @return Language|false Language object or false on failure
      */
     public function getLanguage($code)
     {
@@ -821,17 +868,18 @@ class LanguageManager
         if (isset($langs[$code])) {
             return $langs[$code];
         }
+
         return false;
     }
 
     /**
      * Return currently active Language object
      *
-     * @return object Language object
+     * @return Language Language object
      */
     public function getCurrentLanguage()
     {
-        return $this->_available_languages[strtolower($GLOBALS['lang'])];
+        return $this->availableLanguages[strtolower($GLOBALS['lang'])];
     }
 
     /**
@@ -843,12 +891,13 @@ class LanguageManager
     public function selectLanguage()
     {
         // check forced language
-        if (! empty($GLOBALS['PMA_Config']->get('Lang'))) {
-            $lang = $this->getLanguage($GLOBALS['PMA_Config']->get('Lang'));
+        if (! empty($GLOBALS['config']->get('Lang'))) {
+            $lang = $this->getLanguage($GLOBALS['config']->get('Lang'));
             if ($lang !== false) {
                 return $lang;
             }
-            $this->_lang_failed_cfg = true;
+
+            $this->langFailedConfig = true;
         }
 
         // Don't use REQUEST in following code as it might be confused by cookies
@@ -858,7 +907,8 @@ class LanguageManager
             if ($lang !== false) {
                 return $lang;
             }
-            $this->_lang_failed_request = true;
+
+            $this->langFailedRequest = true;
         }
 
         // check user requested language (GET)
@@ -867,16 +917,18 @@ class LanguageManager
             if ($lang !== false) {
                 return $lang;
             }
-            $this->_lang_failed_request = true;
+
+            $this->langFailedRequest = true;
         }
 
         // check previous set language
-        if (! empty($GLOBALS['PMA_Config']->getCookie('pma_lang'))) {
-            $lang = $this->getLanguage($GLOBALS['PMA_Config']->getCookie('pma_lang'));
+        if (! empty($GLOBALS['config']->getCookie('pma_lang'))) {
+            $lang = $this->getLanguage($GLOBALS['config']->getCookie('pma_lang'));
             if ($lang !== false) {
                 return $lang;
             }
-            $this->_lang_failed_cookie = true;
+
+            $this->langFailedCookie = true;
         }
 
         $langs = $this->availableLanguages();
@@ -904,8 +956,8 @@ class LanguageManager
         }
 
         // Didn't catch any valid lang : we use the default settings
-        if (isset($langs[$GLOBALS['PMA_Config']->get('DefaultLang')])) {
-            return $langs[$GLOBALS['PMA_Config']->get('DefaultLang')];
+        if (isset($langs[$GLOBALS['config']->get('DefaultLang')])) {
+            return $langs[$GLOBALS['config']->get('DefaultLang')];
         }
 
         // Fallback to English
@@ -915,59 +967,17 @@ class LanguageManager
     /**
      * Displays warnings about invalid languages. This needs to be postponed
      * to show messages at time when language is initialized.
-     *
-     * @return void
      */
-    public function showWarnings()
+    public function showWarnings(): void
     {
         // now, that we have loaded the language strings we can send the errors
-        if ($this->_lang_failed_cfg
-            || $this->_lang_failed_cookie
-            || $this->_lang_failed_request
-        ) {
-            trigger_error(
-                __('Ignoring unsupported language code.'),
-                E_USER_ERROR
-            );
-        }
-    }
-
-
-    /**
-     * Returns HTML code for the language selector
-     *
-     * @param boolean $use_fieldset whether to use fieldset for selection
-     * @param boolean $show_doc     whether to show documentation links
-     *
-     * @return string
-     *
-     * @access  public
-     */
-    public function getSelectorDisplay($use_fieldset = false, $show_doc = true)
-    {
-        $_form_params = array(
-            'db' => $GLOBALS['db'],
-            'table' => $GLOBALS['table'],
-        );
-
-        // For non-English, display "Language" with emphasis because it's
-        // not a proper word in the current language; we show it to help
-        // people recognize the dialog
-        $language_title = __('Language')
-            . (__('Language') != 'Language' ? ' - <em>Language</em>' : '');
-        if ($show_doc) {
-            $language_title .= Util::showDocu('faq', 'faq7-2');
+        if (! $this->langFailedConfig && ! $this->langFailedCookie && ! $this->langFailedRequest) {
+            return;
         }
 
-        $available_languages = $this->sortedLanguages();
-
-        return Template::get('select_lang')->render(
-            array(
-                'language_title' => $language_title,
-                'use_fieldset' => $use_fieldset,
-                'available_languages' => $available_languages,
-                '_form_params' => $_form_params,
-            )
+        trigger_error(
+            __('Ignoring unsupported language code.'),
+            E_USER_ERROR
         );
     }
 }
